@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Changes file management - ~/lib/Changes/Release.pm
-## Version v0.2.0
+## Version v0.2.1
 ## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2022/11/23
-## Modified 2022/12/09
+## Modified 2022/12/18
 ## All rights reserved
 ## 
 ## 
@@ -26,7 +26,7 @@ BEGIN
     use Want;
     our $VERSION_CLASS = 'Changes::Version';
     our $DEFAULT_DATETIME_FORMAT = '%FT%T%z';
-    our $VERSION = 'v0.2.0';
+    our $VERSION = 'v0.2.1';
 };
 
 use strict;
@@ -181,6 +181,17 @@ sub as_string
     {
         $fmt_pattern = $DEFAULT_DATETIME_FORMAT;
     }
+    if( defined( $tz ) )
+    {
+        try
+        {
+            $dt->set_time_zone( $tz );
+        }
+        catch( $e )
+        {
+            warn( "Warning only: error trying to set the time zone '", $tz->name, "' (", overload::StrVal( $tz ), ") to DateTime object: $e\n" ) if( $self->_warnings_is_enabled( 'Changes' ) );
+        }
+    }
     if( defined( $fmt_pattern ) && 
         length( "$fmt_pattern" ) )
     {
@@ -541,7 +552,7 @@ Changes::Release - Release object class
 
 =head1 VERSION
 
-    v0.2.0
+    v0.2.1
 
 =head1 DESCRIPTION
 
